@@ -1,11 +1,12 @@
+from __future__ import print_function
 import time, copy, sys, unittest
 # Skip test if cuda_ndarray is not available.
 from nose.plugins.skip import SkipTest
 
 import numpy
+from six.moves import xrange
 
 import theano
-from theano.compat.python2x import all
 import theano.sandbox.cuda as cuda_ndarray
 from theano.tensor.basic import _allclose
 from theano.tests import unittest_tools as utt
@@ -52,28 +53,28 @@ def test_host_to_device():
 
 def test_add_iadd_idiv():
     for shapes in (
-                  [(5,5),(5,1)],
-                  [(5,5),(1,5)],
-                  (), (0,), (3,), (2,3),
-                  (1,10000000),(10000,1000),(1000000,10),
-                  (4100,33,34),(33,4100,34),(33,34,4100),
-                  (4100,33,3,6),(33,4100,3,6),(33,3,4100,6),(33,3,6,4100),
-                  (4100,3,34,6),(3,4100,34,6),(3,34,4100,6),(3,34,6,4100),
-                  (4100,3,4,36),(3,4100,4,36),(3,4,4100,36),(3,4,36,4100),
-                  (0,0,0,0,0),
-                  (3,34,35,36,37),
-                  (33,34,3,36,37),
-                  (33,34,35,36,3),
-                  (0,0,0,0,0,0),
-                  (3,34,35,36,37,2),
-                  (33,34,3,36,37,2),
-                  (33,34,35,36,3,2),
-                  (3,4,5,6,7,1025),
-                  (3,4,5,6,1025,7),
-                  (3,4,5,1025,6,7),
-                  (3,4,1025,5,6,7),
-                  (3,1025,4,5,6,7),
-                  (1025,3,4,5,6,7),
+                  [(5, 5), (5, 1)],
+                  [(5, 5), (1, 5)],
+                  (), (0,), (3,), (2, 3),
+                  (1, 10000000), (10000, 1000), (1000000, 10),
+                  (4100, 33, 34), (33, 4100, 34), (33, 34, 4100),
+                  (4100, 33, 3, 6), (33, 4100, 3, 6), (33, 3, 4100, 6), (33, 3, 6, 4100),
+                  (4100, 3, 34, 6), (3, 4100, 34, 6), (3, 34, 4100, 6), (3, 34, 6, 4100),
+                  (4100, 3, 4, 36), (3, 4100, 4, 36), (3, 4, 4100, 36), (3, 4, 36, 4100),
+                  (0, 0, 0, 0, 0),
+                  (3, 34, 35, 36, 37),
+                  (33, 34, 3, 36, 37),
+                  (33, 34, 35, 36, 3),
+                  (0, 0, 0, 0, 0, 0),
+                  (3, 34, 35, 36, 37, 2),
+                  (33, 34, 3, 36, 37, 2),
+                  (33, 34, 35, 36, 3, 2),
+                  (3, 4, 5, 6, 7, 1025),
+                  (3, 4, 5, 6, 1025, 7),
+                  (3, 4, 5, 1025, 6, 7),
+                  (3, 4, 1025, 5, 6, 7),
+                  (3, 1025, 4, 5, 6, 7),
+                  (1025, 3, 4, 5, 6, 7),
                   ):
         if isinstance(shapes, tuple):
             shape = shapes
@@ -107,11 +108,11 @@ def test_add_iadd_idiv():
             asum = a0 + a1
             t1 = time.time()
             cpu_dt = t1 - t0
-            #print shape, 'adding ', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
+            # print shape, 'adding ', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
             assert numpy.allclose(asum,  numpy.asarray(bsum))
 
-        #test not contiguous version.
-        #should raise not implemented.
+        # test not contiguous version.
+        # should raise not implemented.
         a0 = a0_orig.copy()
         b0 = cuda_ndarray.CudaNdarray(a0)
         if len(shape) == 0:
@@ -149,7 +150,7 @@ def test_add_iadd_idiv():
         a0 += a1
         t1 = time.time()
         cpu_dt = t1 - t0
-        #print shape, 'adding inplace', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
+        # print shape, 'adding inplace', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
         assert numpy.allclose(a0, numpy.asarray(b0))
         assert numpy.allclose(a0, a0_orig + a1)
 
@@ -189,7 +190,7 @@ def test_exp():
         asum = numpy.exp(a1)
         t1 = time.time()
         cpu_dt = t1 - t0
-        #print shape, 'adding ', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
+        # print shape, 'adding ', a0.size, 'cpu', cpu_dt, 'advantage', advantage(cpu_dt, gpu_dt)
         #c = numpy.asarray(b0+b1)
         if asum.shape:
             assert numpy.allclose(asum, numpy.asarray(bsum))
@@ -197,7 +198,7 @@ def test_exp():
 
 def test_copy():
     #print >>sys.stdout, 'starting test_copy'
-    shape = (500,499)
+    shape = (500, 499)
     a = theano._asarray(numpy.random.rand(*shape), dtype='float32')
 
     #print >>sys.stdout, '.. creating device object'
@@ -369,8 +370,8 @@ def test_sum():
     a0sum = a0.sum(axis=0)
     b0sum = b0.reduce_sum([1, 0])
 
-    #print 'asum\n',a0sum
-    #print 'bsum\n',numpy.asarray(b0sum)
+    # print 'asum\n',a0sum
+    # print 'bsum\n',numpy.asarray(b0sum)
 
     assert numpy.allclose(a0.sum(axis=0),
                           numpy.asarray(b0.reduce_sum([1, 0])))
@@ -399,29 +400,28 @@ def test_sum():
 
 def test_reshape():
     shapelist = [
-            ((1,2,3), (1,2,3)),
+            ((1, 2, 3), (1, 2, 3)),
             ((1,), (1,)),
-            ((1,2,3), (3,2,1)),
-            ((1,2,3), (6,)),
-            ((1,2,3,2), (6,2)),
-            ((2,3,2), (6,2)),
-            ((2,3,2), (12,))
+            ((1, 2, 3), (3, 2, 1)),
+            ((1, 2, 3), (6,)),
+            ((1, 2, 3, 2), (6, 2)),
+            ((2, 3, 2), (6, 2)),
+            ((2, 3, 2), (12,))
              ]
 
     bad_shapelist = [
-            ((1,2,3), (1,2,4)),
+            ((1, 2, 3), (1, 2, 4)),
             ((1,), (2,)),
-            ((1,2,3), (2,2,1)),
-            ((1,2,3), (5,)),
-            ((1,2,3,2), (6,3)),
-            ((2,3,2), (5,2)),
-            ((2,3,2), (11,))
+            ((1, 2, 3), (2, 2, 1)),
+            ((1, 2, 3), (5,)),
+            ((1, 2, 3, 2), (6, 3)),
+            ((2, 3, 2), (5, 2)),
+            ((2, 3, 2), (11,))
             ]
 
     utt.seed_rng()
     rng = numpy.random.RandomState(utt.fetch_seed())
 
-
     def subtest(shape_1, shape_2, rng):
         #print >> sys.stdout, "INFO: shapes", shape_1, shape_2
         a = theano._asarray(rng.randn(*shape_1), dtype='float32')
@@ -432,7 +432,7 @@ def test_reshape():
 
         n_bb = numpy.asarray(bb)
 
-        #print n_bb
+        # print n_bb
 
         assert numpy.all(aa == n_bb)
         assert aa.shape == n_bb.shape
@@ -449,7 +449,7 @@ def test_reshape():
 
         n_bb = numpy.asarray(bb)
 
-        #print n_bb
+        # print n_bb
 
         assert numpy.all(aa == n_bb)
         assert aa.shape == n_bb.shape
@@ -458,14 +458,12 @@ def test_reshape():
         a = theano._asarray(rng.randn(*shape_1), dtype='float32')
         b = cuda_ndarray.CudaNdarray(a)
 
-
         try:
             bb = b.reshape(shape_2)
-        except Exception, ValueError:
+        except Exception as ValueError:
             return
         assert False
 
-
     # test working shapes
     for shape_1, shape_2 in shapelist:
         subtest(shape_1, shape_2, rng)
@@ -479,12 +477,12 @@ def test_reshape():
 
 def test_getshape():
     shapelist = [
-            ((1,2,3), (1,2,3)),
+            ((1, 2, 3), (1, 2, 3)),
             ((1,), (1,)),
-            ((1,2,3), (3,2,1)),
-            ((1,2,3), (6,)),
-            ((1,2,3,2), (6,2)),
-            ((2,3,2), (6,2))
+            ((1, 2, 3), (3, 2, 1)),
+            ((1, 2, 3), (6,)),
+            ((1, 2, 3, 2), (6, 2)),
+            ((2, 3, 2), (6, 2))
              ]
 
     def subtest(shape):
@@ -496,9 +494,10 @@ def test_getshape():
         subtest(shape_1)
         subtest(shape_2)
 
+
 def test_stride_manipulation():
 
-    a = theano._asarray([[0,1,2], [3,4,5]], dtype='float32')
+    a = theano._asarray([[0, 1, 2], [3, 4, 5]], dtype='float32')
     b = cuda_ndarray.CudaNdarray(a)
     v = b.view()
     v._dev_data += 0
@@ -516,7 +515,6 @@ def test_stride_manipulation():
     v._dev_data += offset * sizeof_float
     c = numpy.asarray(v)
 
-
     assert numpy.all(c == [[5, 4, 3], [2, 1, 0]])
 
 
@@ -530,8 +528,8 @@ def test_subtensor_broadcastable():
 
 
 def test_copy_subtensor0():
-    sizeof_float=4
-    a = theano._asarray(numpy.random.rand(30,20,5,5), dtype='float32')
+    sizeof_float = 4
+    a = theano._asarray(numpy.random.rand(30, 20, 5, 5), dtype='float32')
     cuda_a = cuda_ndarray.CudaNdarray(a)
     a_view = cuda_a.view()
     a_view_strides = a_view._strides
@@ -541,10 +539,11 @@ def test_copy_subtensor0():
 
     a_view_copy = copy.deepcopy(a_view)
 
-    assert numpy.all(a[:,:,::-1,::-1] == numpy.asarray(a_view_copy))
+    assert numpy.all(a[:, :, ::-1, ::-1] == numpy.asarray(a_view_copy))
+
 
 def test_mapping_getitem_ellipsis():
-    a = theano._asarray(numpy.random.rand(5,4,3,2), dtype='float32')
+    a = theano._asarray(numpy.random.rand(5, 4, 3, 2), dtype='float32')
     a = cuda_ndarray.CudaNdarray(a)
 
     b = a[...]
@@ -552,25 +551,27 @@ def test_mapping_getitem_ellipsis():
     assert b._strides == a._strides
     assert b.shape == a.shape
 
+
 def test_mapping_getitem_reverse_some_dims():
-    dim=(5,4,3,2)
+    dim = (5, 4, 3, 2)
     a = theano._asarray(numpy.random.rand(*dim), dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    _b = _a[:,:,::-1, ::-1]
+    _b = _a[:, :, ::-1, ::-1]
 
     b = numpy.asarray(_b)
-    assert numpy.all(b==a[:,:,::-1,::-1])
+    assert numpy.all(b == a[:, :, ::-1, ::-1])
+
 
 def test_mapping_getitem_w_int():
-    def _cmp(x,y):
+    def _cmp(x, y):
         assert x.shape == y.shape
         if not numpy.all(x == y):
-            print x
-            print y
+            print(x)
+            print(y)
         assert numpy.all(x == y)
 
-    def _cmpf(x,*y):
+    def _cmpf(x, *y):
         try:
             x.__getitem__(y)
         except IndexError:
@@ -578,9 +579,9 @@ def test_mapping_getitem_w_int():
         else:
             raise Exception("Did not generate out or bound error")
 
-    def _cmpfV(x,*y):
+    def _cmpfV(x, *y):
         try:
-            if len(y)==1:
+            if len(y) == 1:
                 x.__getitem__(*y)
             else:
                 x.__getitem__(y)
@@ -589,7 +590,7 @@ def test_mapping_getitem_w_int():
         else:
             raise Exception("Did not generate out or bound error")
 
-    dim =(2,)
+    dim = (2,)
     a = theano._asarray(numpy.random.rand(*dim), dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
     _cmp(numpy.asarray(_a[1]), a[1])
@@ -598,237 +599,246 @@ def test_mapping_getitem_w_int():
     _cmp(numpy.asarray(_a[::1]), a[::1])
     _cmp(numpy.asarray(_a[::-1]), a[::-1])
     _cmp(numpy.asarray(_a[...]), a[...])
-    _cmpf(_a,2)
+    _cmpf(_a, 2)
 
-    dim =()
+    dim = ()
     a = theano._asarray(numpy.random.rand(*dim), dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
     _cmp(numpy.asarray(_a[...]), a[...])
-    _cmpf(_a,0)
-    _cmpfV(_a,slice(1))
+    _cmpf(_a, 0)
+    _cmpfV(_a, slice(1))
 
-    dim =(5,4,3,2)
+    dim = (5, 4, 3, 2)
     a = theano._asarray(numpy.random.rand(*dim), dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    _cmpf(_a,slice(-1),slice(-1),10,-10)
-    _cmpf(_a,slice(-1),slice(-1),-10,slice(-1))
-    _cmpf(_a,0,slice(0,-1,-20),-10)
-    _cmpf(_a,10)
-    _cmpf(_a,(10,0,0,0))
-    _cmpf(_a,-10)
+    _cmpf(_a, slice(-1), slice(-1), 10, -10)
+    _cmpf(_a, slice(-1), slice(-1), -10, slice(-1))
+    _cmpf(_a, 0, slice(0, -1, -20), -10)
+    _cmpf(_a, 10)
+    _cmpf(_a, (10, 0, 0, 0))
+    _cmpf(_a, -10)
 
-    #test with integer
+    # test with integer
     _cmp(numpy.asarray(_a[1]), a[1])
     _cmp(numpy.asarray(_a[-1]), a[-1])
     _cmp(numpy.asarray(_a[numpy.int64(1)]), a[numpy.int64(1)])
     _cmp(numpy.asarray(_a[numpy.int64(-1)]), a[numpy.int64(-1)])
 
-    #test with slice
+    # test with slice
     _cmp(numpy.asarray(_a[1:]), a[1:])
     _cmp(numpy.asarray(_a[1:2]), a[1:2])
     _cmp(numpy.asarray(_a[-1:1]), a[-1:1])
 
+    # test with tuple (mix slice, integer, numpy.int64)
+    _cmp(numpy.asarray(_a[:, :, ::numpy.int64(-1), ::-1]), a[:, :, ::-1, ::-1])
+    _cmp(numpy.asarray(_a[:, :, numpy.int64(1), -1]), a[:, :, 1, -1])
+    _cmp(numpy.asarray(_a[:, :, ::-1, ::-1]), a[:, :, ::-1, ::-1])
+    _cmp(numpy.asarray(_a[:, :, ::-10, ::-10]), a[:, :, ::-10, ::-10])
+    _cmp(numpy.asarray(_a[:, :, 1, -1]), a[:, :, 1, -1])
+    _cmp(numpy.asarray(_a[:, :, -1, :]), a[:, :, -1, :])
+    _cmp(numpy.asarray(_a[:, ::-2, -1, :]), a[:, ::-2, -1, :])
+    _cmp(numpy.asarray(_a[:, ::-20, -1, :]), a[:, ::-20, -1, :])
+    _cmp(numpy.asarray(_a[:, ::-2, -1]), a[:, ::-2, -1])
+    _cmp(numpy.asarray(_a[0, ::-2, -1]), a[0, ::-2, -1])
 
-    #test with tuple (mix slice, integer, numpy.int64)
-    _cmp(numpy.asarray(_a[:,:,::numpy.int64(-1), ::-1]), a[:,:,::-1,::-1])
-    _cmp(numpy.asarray(_a[:,:,numpy.int64(1),-1]), a[:,:,1,-1])
-    _cmp(numpy.asarray(_a[:,:,::-1, ::-1]), a[:,:,::-1,::-1])
-    _cmp(numpy.asarray(_a[:,:,::-10, ::-10]), a[:,:,::-10,::-10])
-    _cmp(numpy.asarray(_a[:,:,1,-1]), a[:,:,1,-1])
-    _cmp(numpy.asarray(_a[:,:,-1,:]), a[:,:,-1,:])
-    _cmp(numpy.asarray(_a[:,::-2,-1,:]), a[:,::-2,-1,:])
-    _cmp(numpy.asarray(_a[:,::-20,-1,:]), a[:,::-20,-1,:])
-    _cmp(numpy.asarray(_a[:,::-2,-1]), a[:,::-2,-1])
-    _cmp(numpy.asarray(_a[0,::-2,-1]), a[0,::-2,-1])
-
-    _cmp(numpy.asarray(_a[-1,-1,-1,-2]), a[-1,-1,-1,-2])
+    _cmp(numpy.asarray(_a[-1, -1, -1, -2]), a[-1, -1, -1, -2])
     _cmp(numpy.asarray(_a[...]), a[...])
 
+
 def test_gemm_vector_vector():
-    a = theano._asarray(numpy.random.rand(5,1), dtype='float32')
+    a = theano._asarray(numpy.random.rand(5, 1), dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
-    b = theano._asarray(numpy.random.rand(1,5), dtype='float32')
+    b = theano._asarray(numpy.random.rand(1, 5), dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
-    _c = cuda_ndarray.dot(_a,_b)
-    assert _c.shape == (5,5)
+    _c = cuda_ndarray.dot(_a, _b)
+    assert _c.shape == (5, 5)
     assert numpy.allclose(_c, numpy.dot(a, b))
 
-    _c = cuda_ndarray.dot(_b,_a)
-    assert _c.shape == (1,1)
+    _c = cuda_ndarray.dot(_b, _a)
+    assert _c.shape == (1, 1)
     assert numpy.allclose(_c, numpy.dot(b, a))
 
 # ---------------------------------------------------------------------
 
+
 def test_setitem_matrixscalar0():
-    a = theano._asarray([[0,1,2], [3,4,5]], dtype='float32')
+    a = theano._asarray([[0, 1, 2], [3, 4, 5]], dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
     b = theano._asarray(8, dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     # set an element to 8
-    _a[1,1] = _b
-    a[1,1] = b
-    assert numpy.allclose(a,numpy.asarray(_a))
+    _a[1, 1] = _b
+    a[1, 1] = b
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    #test direct transfert from numpy
-    _a[1,1] = theano._asarray(888, dtype='float32')
-    a[1,1] = theano._asarray(888, dtype='float32')
-    assert numpy.allclose(a,numpy.asarray(_a))
+    # test direct transfert from numpy
+    _a[1, 1] = theano._asarray(888, dtype='float32')
+    a[1, 1] = theano._asarray(888, dtype='float32')
+    assert numpy.allclose(a, numpy.asarray(_a))
 
     # broadcast a 0
     _a[1, 1] = 0
     _a[0:2] = 0
     _a[1:] = 0
 
+
 def test_setitem_matrixvector1():
-    a = theano._asarray([[0,1,2], [3,4,5]], dtype='float32')
+    a = theano._asarray([[0, 1, 2], [3, 4, 5]], dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([8,9], dtype='float32')
+    b = theano._asarray([8, 9], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     # set second column to 8,9
-    _a[:,1] = _b
-    a[:,1] = b
-    assert numpy.allclose(a,numpy.asarray(_a))
+    _a[:, 1] = _b
+    a[:, 1] = b
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    #test direct transfert from numpy
-    _a[:,1] =  b*100
-    a[:,1] =  b*100
-    assert numpy.allclose(a,numpy.asarray(_a))
+    # test direct transfert from numpy
+    _a[:, 1] =  b*100
+    a[:, 1] =  b*100
+    assert numpy.allclose(a, numpy.asarray(_a))
+
+    row = theano._asarray([777, 888, 999], dtype='float32')
+    _a[1, :] = row
+    a[1, :] = row
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    row = theano._asarray([777,888,999], dtype='float32')
-    _a[1,:] = row
-    a[1,:] = row
-    assert numpy.allclose(a,numpy.asarray(_a))
 
 def test_setitem_matrix_tensor3():
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8,9], dtype='float32')
+    b = theano._asarray([7, 8, 9], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     # set middle row through cube to 7,8,9
-    _a[:,1,1] = _b
+    _a[:, 1, 1] = _b
 
-    a[:,1,1] = b
-    assert numpy.allclose(a,numpy.asarray(_a))
+    a[:, 1, 1] = b
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    #test direct transfert from numpy
-    _a[:,1,1] = b*100
-    a[:,1,1] = b*100
-    assert numpy.allclose(a,numpy.asarray(_a))
+    # test direct transfert from numpy
+    _a[:, 1, 1] = b*100
+    a[:, 1, 1] = b*100
+    assert numpy.allclose(a, numpy.asarray(_a))
+
+    row = theano._asarray([777, 888, 999], dtype='float32')
+    _a[1, 1, :] = row
+    a[1, 1, :] = row
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    row = theano._asarray([777,888,999], dtype='float32')
-    _a[1,1,:] = row
-    a[1,1,:] = row
-    assert numpy.allclose(a,numpy.asarray(_a))
 
 def test_setitem_from_numpy_error():
     pass
 
+
 def test_setitem_matrix_bad_shape():
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8], dtype='float32')
+    b = theano._asarray([7, 8], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     try:
         # attempt to assign the ndarray b with setitem
-        _a[:,1,1] = _b
+        _a[:, 1, 1] = _b
         assert False
-    except ValueError, e:
-        #print e
+    except ValueError as e:
+        # print e
         assert True
 
-    #test direct transfert from numpy
+    # test direct transfert from numpy
     try:
         # attempt to assign the ndarray b with setitem
-        _a[1,1,:] = b
+        _a[1, 1, :] = b
         assert False
-    except ValueError, e:
-        #print e
+    except ValueError as e:
+        # print e
         assert True
 
+
 def test_setitem_matrix_bad_ndim():
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8], dtype='float32')
+    b = theano._asarray([7, 8], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     try:
         # attempt to assign the ndarray b with setitem
-        _a[:,:,1] = _b
+        _a[:, :, 1] = _b
         assert False
-    except ValueError, e:
-        #print e
+    except ValueError as e:
+        # print e
         assert True
 
-    #test direct transfert from numpy
+    # test direct transfert from numpy
     try:
         # attempt to assign the ndarray b with setitem
-        _a[1,:,:] = b
+        _a[1, :, :] = b
         assert False
-    except ValueError, e:
-        #print e
+    except ValueError as e:
+        # print e
         assert True
 
+
 def test_setitem_matrix_bad_type():
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8], dtype='float64')
+    b = theano._asarray([7, 8], dtype='float64')
 
-    #test direct transfert from numpy
+    # test direct transfert from numpy
     try:
         # attempt to assign the ndarray b with setitem
-        _a[1,:,:] = b
+        _a[1, :, :] = b
         assert False
-    except TypeError, e:
-        #print e
+    except TypeError as e:
+        # print e
         assert True
 
+
 def test_setitem_assign_to_slice():
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8,9], dtype='float32')
+    b = theano._asarray([7, 8, 9], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
 
     # first get a slice of a
-    _c = _a[:,:,1]
+    _c = _a[:, :, 1]
 
     # set middle row through cube to 7,8,9
     # (this corresponds to middle row of matrix _c)
-    _c[:,1] = _b
+    _c[:, 1] = _b
 
-    a[:,:,1][:,1] = b
-    assert numpy.allclose(a,numpy.asarray(_a))
+    a[:, :, 1][:, 1] = b
+    assert numpy.allclose(a, numpy.asarray(_a))
+
+    # test direct transfert from numpy
+    _d = _a[1, :, :]
+    _d[1, :] = b*10
+    a[1, :, :][1, :] = b*10
+    assert numpy.allclose(a, numpy.asarray(_a))
 
-    #test direct transfert from numpy
-    _d = _a[1,:,:]
-    _d[1,:] = b*10
-    a[1,:,:][1,:] = b*10
-    assert numpy.allclose(a,numpy.asarray(_a))
 
 def test_setitem_broadcast():
-    #test scalar to vector without stride
+    # test scalar to vector without stride
     a = numpy.arange(3)
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
@@ -837,36 +847,36 @@ def test_setitem_broadcast():
     _b = cuda_ndarray.CudaNdarray(b)
     _a[:] = _b.reshape((1,))
     a[:] = b.reshape((1,))
-    assert numpy.allclose(numpy.asarray(_a),a)
+    assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test vector to matrice without stride
+    # test vector to matrice without stride
     a = numpy.arange(9)
-    a.resize((3,3))
+    a.resize((3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([7,8,9], dtype='float32')
+    b = theano._asarray([7, 8, 9], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)
-    _a[:,:] = _b.reshape((1,3))
-    a[:,:] = b.reshape((1,3))
-    assert numpy.allclose(numpy.asarray(_a),a)
+    _a[:, :] = _b.reshape((1, 3))
+    a[:, :] = b.reshape((1, 3))
+    assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test vector to matrice with stride
+    # test vector to matrice with stride
     a = numpy.arange(27)
-    a.resize((3,3,3))
+    a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
 
-    b = theano._asarray([[7,8,9],[10,11,12]], dtype='float32')
+    b = theano._asarray([[7, 8, 9], [10, 11, 12]], dtype='float32')
     _b = cuda_ndarray.CudaNdarray(b)[0]
     b = b[0]
-    _a[:,:,1] = _b.reshape((1,3))
-    a[:,:,1] = b.reshape((1,3))
-    assert numpy.allclose(numpy.asarray(_a),a)
+    _a[:, :, 1] = _b.reshape((1, 3))
+    a[:, :, 1] = b.reshape((1, 3))
+    assert numpy.allclose(numpy.asarray(_a), a)
 
 
 def test_setitem_broadcast_numpy():
-    #test scalar to vector without stride
+    # test scalar to vector without stride
     a = numpy.arange(3)
     a = theano._asarray(a, dtype='float32')
     _a = cuda_ndarray.CudaNdarray(a)
@@ -876,7 +886,7 @@ def test_setitem_broadcast_numpy():
     a[:] = b.reshape((1,))
     assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test vector to matrice without stride
+    # test vector to matrice without stride
     a = numpy.arange(9)
     a.resize((3, 3))
     a = theano._asarray(a, dtype='float32')
@@ -887,7 +897,7 @@ def test_setitem_broadcast_numpy():
     a[:, :] = b.reshape((1, 3))
     assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test vector to matrice with stride
+    # test vector to matrice with stride
     a = numpy.arange(27)
     a.resize((3, 3, 3))
     a = theano._asarray(a, dtype='float32')
@@ -920,7 +930,7 @@ def test_setitem_rightvalue_ndarray_fails():
     a[:, :, 1] = b
     assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test direct transfert from numpy to contiguous region
+    # test direct transfert from numpy to contiguous region
     # attempt to assign the ndarray b with setitem
     # same number of dim
     mat = numpy.random.rand(4, 5).astype('float32')
@@ -933,15 +943,15 @@ def test_setitem_rightvalue_ndarray_fails():
         _a[0, :, :] = mat
         #a[0, :, :] = mat
         #assert numpy.allclose(numpy.asarray(_a), a)
-    except ValueError, e:
+    except ValueError as e:
         pass
 
-    #test direct transfert from numpy with broadcast
+    # test direct transfert from numpy with broadcast
     _a[0, :, :] = b5
     a[0, :, :] = b5
     assert numpy.allclose(numpy.asarray(_a), a)
 
-    #test direct transfert from numpy to not contiguous region
+    # test direct transfert from numpy to not contiguous region
     # attempt to assign the ndarray b with setitem
     _a[:, :, 2] = b
     a[:, :, 2] = b
@@ -949,7 +959,7 @@ def test_setitem_rightvalue_ndarray_fails():
 
 
 def test_zeros_basic():
-    for shp in [(3,4,5), (300,), (), (0,7)]:
+    for shp in [(3, 4, 5), (300,), (), (0, 7)]:
         _a = cuda_ndarray.CudaNdarray.zeros(shp)
         _n = numpy.zeros(shp, dtype="float32")
         assert numpy.allclose(numpy.asarray(_a), _n)
@@ -958,13 +968,12 @@ def test_zeros_basic():
 
     # TODO:The following don't have the same stride!
     #      This should be fixed with the new GpuNdArray.
-    for shp in [(3,0), (4,1,5)]:
+    for shp in [(3, 0), (4, 1, 5)]:
         _a = cuda_ndarray.CudaNdarray.zeros(shp)
         _n = numpy.zeros(shp, dtype="float32")
         assert numpy.allclose(numpy.asarray(_a), _n)
         assert _a.shape == _n.shape
 
-
     try:
         _n = numpy.zeros()
     except TypeError:
@@ -982,18 +991,18 @@ def test_zeros_basic():
 def test_base():
     # Test that the 'base' attribute of a CudaNdarray is the one
     # built initially, not an intermediate one.
-    a = cuda_ndarray.CudaNdarray.zeros((3,4,5))
+    a = cuda_ndarray.CudaNdarray.zeros((3, 4, 5))
     for i in xrange(5):
         b = a[:]
     assert b.base is a
 
     c = a[0]
-    d = c[:,0]
-    #print d.shape
+    d = c[:, 0]
+    # print d.shape
     assert c.base is a
     assert d.base is a
 
-    e = b.reshape((5,2,2,3))
+    e = b.reshape((5, 2, 2, 3))
     assert e.base is a
 
 
@@ -1024,7 +1033,7 @@ def test_set_strides():
 
 
 def test_is_c_contiguous():
-    a = cuda_ndarray.CudaNdarray.zeros((3,4,5))
+    a = cuda_ndarray.CudaNdarray.zeros((3, 4, 5))
     assert a.is_c_contiguous()
     assert a[1].is_c_contiguous()
     assert not a[::2].is_c_contiguous()
